@@ -1,4 +1,4 @@
-# Gufw 17.04.0 - http://gufw.org
+# Gufw 17.04.1 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -253,7 +253,7 @@ class Firewall():
         if exclude_iface:
             try:
                 all_faces.remove(exclude_iface)
-            except:
+            except Exception:
                 pass
         
         return all_faces
