@@ -1,4 +1,4 @@
-# Gufw 17.04.0 - http://gufw.org
+# Gufw 17.04.1 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -137,7 +137,7 @@ class Add:
             self.preconfig_category.append_text(cat)
         try:
             self.preconfig_category.set_active(categories.index(_("All")))
-        except:
+        except Exception:
             self.preconfig_category.set_active(0)
         
         subcategories = self.apps.get_subcategories(self.preconfig_category.get_active_text())
@@ -545,7 +545,7 @@ class AppProfiles:
             if current_cat == category or category == _("All"):
                 try:
                     current_subcat = cat.split(';')[1]
-                except:
+                except Exception:
                     current_subcat = ''
                 if not subcateg.count(current_subcat) and current_subcat:
                     subcateg.append(current_subcat)
@@ -561,7 +561,7 @@ class AppProfiles:
                 current_cat = category.split(';')[0]
                 try:
                     current_subcat = category.split(';')[1]
-                except:
+                except Exception:
                     current_subcat = ''
                 
                 if cat == _("All") and subcat == _("All"):
