@@ -1,4 +1,4 @@
-# Gufw 17.04.0 - http://gufw.org
+# Gufw 17.04.1 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -178,7 +178,7 @@ class Gufw:
         self.viewport_home  = self.builder.get_object('viewport_home')
         self.viewport_home.reparent(vbox_home)
         stack.add_titled(vbox_home, "tutorial", _("Getting started"))
-        stack.child_set_property(vbox_home, "icon-name", "gtk-home") # Set icon
+        stack.child_set_property(vbox_home, "icon-name", "go-home") # Set icon
         # Stack 2 = Rules
         vbox_rules = Gtk.Box()
         self.viewport_rules  = self.builder.get_object('viewport_rules')
@@ -330,7 +330,7 @@ class Gufw:
         distro = platform.linux_distribution()[0].lower()
         try:
             user = sys.argv[1]
-        except:
+        except Exception:
             self.show_dialog(self.winMain, _("Visit this web (please, copy & paste in your browser):"), url)
             return
         
@@ -481,7 +481,7 @@ class Gufw:
     def on_routed_changed(self, widget, data=None):
         try: # Could be inconsistent between imports and changes of Routed status
             self.fw.set_policy('routed', self.NUM2POLICY[self.routed.get_active()].lower())
-        except:
+        except Exception:
             return
         self._set_shield()
         self.add_to_log(_("Routed: ") + self.routed.get_active_text(), self.POLICY2COLOR[self.fw.get_policy('routed')])
@@ -579,7 +579,7 @@ class Gufw:
         while True:
             try:
                 iter_row = model.get_iter(i,)
-            except:
+            except Exception:
                 return i
             i += 1
     
